#!/usr/bin/perl -w

use strict;
use CGI qw(:standard);
use DBI;
use Batts;

#########################
# subroutine declarations

sub do_params;
sub list_cust_tickets;
sub list_new_tickets;
sub read_config;
sub single_ticket;
sub standard_footer;
sub standard_header;

#######################
# variable declarations

my $show_menu;

########################
# initialization stuff

$is_html="1"; 		# set HTML capability, as we're a Web page

read_config;		# local function to get info from the config file

batts_db_connect; 	# connect to the database and load table data

load_billing;
load_category;
load_customer;
load_people;
load_priorities;
load_status;

######################
# Main page

standard_header;

# check for any parameters first
$show_menu = do_params;

if ($show_menu) {
	list_new_tickets;
	list_cust_tickets;
	single_ticket;
}

standard_footer;

# end main page
#######################


################################################################
# do_params -- process parameters and do the appropriate output

sub do_params {
	
	my $custname = param('customer_name');
	my $ticketid = param('ticketid');

	# Customer ticket list
   if ($custname) {

      my $shortname;
      foreach (sort keys %customer) {
         if ($customer{$_}[1] eq $custname) {
            $shortname = $customer[$customer{$_}[0]];
         }
      }

      show_cust_ticket($shortname);
		return 0;
   }

	# Single ticket
	if ($ticketid) {
		show_ticket($ticketid);

		# show the log if asked
		if (param('log')) {
			show_ticket_log($ticketid);
		}

		return 0;
	}

	# New ticket flag -- hidden param
	if (param('new_tickets')) {
		show_new;
		return 0;
	}

	# nothing to print, so show the menu
	return 1;  
}


#######################################################
# list_cust_tickets -- a form to show customer tickets
# params:	customer_name

sub list_cust_tickets {

	# build an array of full names for display
	my @fullnames;
	foreach (sort keys %customer) {
   	push @fullnames, $customer{$_}[1];
	}

	# make a form to select the customer tickets to display
	print	h3('Show a customer\'s tickets'),
		start_form,
		popup_menu(-name=>'customer_name',-value=>[@fullnames]),
		submit,
		end_form;
}

####################################################
# list_new_tickets -- a form to list all new tickets
# params:	new_tickets HIDDEN

sub list_new_tickets {

	print h3('Show all new tickets'),
		start_form,
		hidden(-name=>'new_tickets',-value=>"1"),
		submit,
		end_form;
}

#######################################################################
# read_config -- initialize database variables (and others if needed)

sub read_config {
	my %config;

	open(CONFIG, "< $db_config_file") # get config file from a library variable
	or die "Couldn't open $db_config_file for reading: $!\n";

	while (<CONFIG>) {
		chomp;                  # no newline
		s/#.*//;                # no comments
		s/^\s+//;               # no leading white
		s/\s+$//;               # no trailing white
		next unless length;     # anything left?
		my ($var, $value) = split(/\s*=\s*/, $_, 2);
		$config{$var} = $value;
	}

	close(CONFIG);

	$host_name = $config{"host"};	# store values into library-global variables
	$user_name = $config{"user"};
	$password  = $config{"pass"};
}

############################################################
# single_ticket -- a form to show, well, a single ticket
# params: ticketid
sub single_ticket {
	
	print h3('Display a single ticket'),
			start_form,
			"Ticket ID ", textfield('ticketid'),
			submit, end_form;
}

#######################################
# standard_footer -- for completion

sub standard_footer {
	print end_html;
}

#################################
# standard_header -- always display this stuff first

sub standard_header { 
	print header,
			start_html('batts trouble ticket system'),
			"Welcome to ", a({href=>url()},'batts'),hr;
}
